@@ -80,25 +80,26 @@ namespace ranges
         template<typename Inner>
         struct store_inner_
         {
-            views::all_t<Inner> inner_ = views::all_t<Inner>();
+            non_propagating_cache<std::remove_cv_t<Inner>> inner_ = {};
 
-            constexpr views::all_t<Inner> & update_inner_(Inner && inner)
+            template<typename OuterIt>
+            constexpr auto && update_inner_(OuterIt && it)
             {
-                return (inner_ = views::all(static_cast<Inner &&>(inner)));
+                return inner_.emplace_deref(it);
             }
-            constexpr views::all_t<Inner> & get_inner_(ignore_t) noexcept
+            constexpr Inner & get_inner_(ignore_t) noexcept
             {
-                return inner_;
+                return *inner_;
             }
         };
 
         struct pass_thru_inner_
         {
             // Intentionally promote xvalues to lvalues here:
-            template<typename Inner>
-            static constexpr Inner & update_inner_(Inner && inner) noexcept
+            template<typename OuterIt>
+            static constexpr auto && update_inner_(OuterIt && it) noexcept
             {
-                return inner;
+                return *it;
             }
             template<typename OuterIt>
             static constexpr decltype(auto) get_inner_(OuterIt && outer_it)
@@ -113,6 +114,8 @@ namespace ranges
                       store_inner_<range_reference_t<Rng>>, pass_thru_inner_>;
 
         // clang-format off
+        /// \concept has_member_arrow_
+        /// \brief The \c has_member_arrow_ concept
         template<typename I>
         CPP_requires(has_member_arrow_,
             requires(I i) //
@@ -120,6 +123,8 @@ namespace ranges
                 i.operator->()
             ));
 
+        /// \concept has_arrow_
+        /// \brief The \c has_arrow_ concept
         template<typename I>
         CPP_concept has_arrow_ =
             input_iterator<I> &&
@@ -139,8 +144,6 @@ namespace ranges
     {
         CPP_assert(input_range<Rng> && view_<Rng>);
         CPP_assert(input_range<range_reference_t<Rng>>);
-        CPP_assert(std::is_reference<range_reference_t<Rng>>::value ||
-                   view_<range_reference_t<Rng>>);
 
         join_view() = default;
         explicit join_view(Rng rng)
@@ -150,15 +153,13 @@ namespace ranges
         CPP_member
         static constexpr auto size() //
             -> CPP_ret(std::size_t)(
-                /// \pre
                 requires (detail::join_cardinality<Rng>() >= 0))
         {
             return static_cast<std::size_t>(detail::join_cardinality<Rng>());
         }
         // Not to spec
-        CPP_member
+        CPP_auto_member
         constexpr auto CPP_fun(size)()(
-            /// \pre
             requires(detail::join_cardinality<Rng>() < 0) &&
                 (range_cardinality<Rng>::value >= 0) &&
                 forward_range<Rng> &&
@@ -196,7 +197,7 @@ namespace ranges
             {
                 for(; outer_it_ != ranges::end(rng_->outer_); ++outer_it_)
                 {
-                    auto & inner = rng_->update_inner_(*outer_it_);
+                    auto && inner = rng_->update_inner_(outer_it_);
                     inner_it_ = ranges::begin(inner);
                     if(inner_it_ != ranges::end(inner))
                         return;
@@ -218,7 +219,6 @@ namespace ranges
                 satisfy();
             }
             template(bool Other)(
-                /// \pre
                 requires Const AND CPP_NOT(Other) AND
                 convertible_to<iterator_t<Rng>, iterator_t<COuter>> AND
                 convertible_to<iterator_t<range_reference_t<Rng>>,
@@ -231,7 +231,6 @@ namespace ranges
             CPP_member
             constexpr auto arrow() //
                 -> CPP_ret(iterator_t<CInner>)(
-                    /// \pre
                     requires detail::has_arrow_<iterator_t<CInner>>)
             {
                 return inner_it_;
@@ -243,7 +242,6 @@ namespace ranges
             CPP_member
             constexpr auto equal(cursor const & that) const //
                 -> CPP_ret(bool)(
-                    /// \pre
                     requires ref_is_glvalue::value && //
                         equality_comparable<iterator_t<COuter>> && //
                         equality_comparable<iterator_t<CInner>>)
@@ -262,7 +260,6 @@ namespace ranges
             CPP_member
             constexpr auto prev() //
                 -> CPP_ret(void)(
-                    /// \pre
                     requires ref_is_glvalue::value && //
                         bidirectional_range<COuter> && //
                         bidirectional_range<CInner> && //
@@ -318,7 +315,6 @@ namespace ranges
         }
 
         template(bool Const = true)(
-            /// \pre
             requires Const AND input_range<meta::const_if_c<Const, Rng>> AND
                 std::is_reference<range_reference_t<meta::const_if_c<Const, Rng>>>::value)
         constexpr cursor<Const> begin_cursor() const
@@ -336,7 +332,6 @@ namespace ranges
         }
 
         template(bool Const = true)(
-            /// \pre
             requires Const AND input_range<meta::const_if_c<Const, Rng>> AND
                 std::is_reference<range_reference_t<meta::const_if_c<Const, Rng>>>::value)
         constexpr auto end_cursor() const
@@ -356,6 +351,7 @@ namespace ranges
     template<typename Rng, typename ValRng>
     struct join_with_view
       : view_facade<join_with_view<Rng, ValRng>, detail::join_cardinality<Rng, ValRng>()>
+      , private detail::join_view_inner<Rng>
     {
         CPP_assert(input_range<Rng>);
         CPP_assert(input_range<range_reference_t<Rng>>);
@@ -373,12 +369,11 @@ namespace ranges
         CPP_member
         static constexpr auto size() //
             -> CPP_ret(std::size_t)(
-                /// \pre
                 requires (detail::join_cardinality<Rng, ValRng>() >= 0))
         {
             return static_cast<std::size_t>(detail::join_cardinality<Rng, ValRng>());
         }
-        CPP_member
+        CPP_auto_member
         auto CPP_fun(size)()(const //
             requires(detail::join_cardinality<Rng, ValRng>() < 0) &&
                 (range_cardinality<Rng>::value >= 0) && forward_range<Rng> &&
@@ -399,7 +394,6 @@ namespace ranges
         using Inner = views::all_t<range_reference_t<Outer> &>;
 
         Outer outer_{};
-        Inner inner_{};
         views::all_t<ValRng> val_{};
 
         class cursor
@@ -417,13 +411,13 @@ namespace ranges
                         if(ranges::get<0>(cur_) != ranges::end(rng_->val_))
                             break;
                         // Intentionally promote xvalues to lvalues here:
-                        auto && tmp = *outer_it_;
-                        rng_->inner_ = views::all(tmp);
-                        ranges::emplace<1>(cur_, ranges::begin(rng_->inner_));
+                        auto && inner = rng_->update_inner_(outer_it_);
+                        ranges::emplace<1>(cur_, ranges::begin(inner));
                     }
                     else
                     {
-                        if(ranges::get<1>(cur_) != ranges::end(rng_->inner_))
+                        auto && inner = rng_->get_inner_(outer_it_);
+                        if(ranges::get<1>(cur_) != ranges::end(inner))
                             break;
                         if(++outer_it_ == ranges::end(rng_->outer_))
                             break;
@@ -446,10 +440,8 @@ namespace ranges
             {
                 if(outer_it_ != ranges::end(rng->outer_))
                 {
-                    // Intentionally promote xvalues to lvalues here:
-                    auto && tmp = *outer_it_;
-                    rng->inner_ = views::all(tmp);
-                    ranges::emplace<1>(cur_, ranges::begin(rng->inner_));
+                    auto && inner = rng_->update_inner_(outer_it_);
+                    ranges::emplace<1>(cur_, ranges::begin(inner));
                     satisfy();
                 }
             }
@@ -469,7 +461,10 @@ namespace ranges
                 else
                 {
                     auto & it = ranges::get<1>(cur_);
-                    RANGES_ASSERT(it != ranges::end(rng_->inner_));
+                    #ifndef NDEBUG
+                    auto && inner = rng_->get_inner_(outer_it_);
+                    RANGES_ASSERT(it != ranges::end(inner));
+                    #endif
                     ++it;
                 }
                 satisfy();
@@ -504,17 +499,21 @@ namespace ranges
         // Don't forget to update views::for_each whenever this set
         // of concepts changes
         // clang-format off
+        /// \concept joinable_range_
+        /// \brief The \c joinable_range_ concept
         template(typename Rng)(
         concept (joinable_range_)(Rng),
-            input_range<range_reference_t<Rng>> AND
-            (std::is_reference<range_reference_t<Rng>>::value ||
-                view_<range_reference_t<Rng>>)
+            input_range<range_reference_t<Rng>>
         );
+        /// \concept joinable_range
+        /// \brief The \c joinable_range concept
         template<typename Rng>
         CPP_concept joinable_range =
             viewable_range<Rng> && input_range<Rng> &&
             CPP_concept_ref(views::joinable_range_, Rng);
 
+        /// \concept joinable_with_range_
+        /// \brief The \c joinable_with_range_ concept
         template(typename Rng, typename ValRng)(
         concept (joinable_with_range_)(Rng, ValRng),
             common_with<
@@ -531,6 +530,8 @@ namespace ranges
                 range_rvalue_reference_t<ValRng>,
                 range_rvalue_reference_t<range_reference_t<Rng>>>
         );
+        /// \concept joinable_with_range
+        /// \brief The \c joinable_with_range concept
         template<typename Rng, typename ValRng>
         CPP_concept joinable_with_range =
             joinable_range<Rng> &&
@@ -542,7 +543,6 @@ namespace ranges
         struct cpp20_join_fn
         {
             template(typename Rng)(
-                /// \pre
                 requires joinable_range<Rng>)
             join_view<all_t<Rng>> operator()(Rng && rng) const
             {
@@ -559,7 +559,6 @@ namespace ranges
             using cpp20_join_fn::operator();
 
             template(typename Rng)(
-                /// \pre
                 requires joinable_with_range<Rng, single_view<inner_value_t<Rng>>>)
             join_with_view<all_t<Rng>, single_view<inner_value_t<Rng>>> //
             operator()(Rng && rng, inner_value_t<Rng> v) const
@@ -568,7 +567,6 @@ namespace ranges
             }
 
             template(typename Rng, typename ValRng)(
-                /// \pre
                 requires joinable_with_range<Rng, ValRng>)
             join_with_view<all_t<Rng>, all_t<ValRng>> //
             operator()(Rng && rng, ValRng && val) const
@@ -589,14 +587,12 @@ namespace ranges
         struct join_bind_fn
         {
             template(typename T)(
-                /// \pre
                 requires (!joinable_range<T>)) // TODO: underconstrained
             constexpr auto operator()(T && t)const
             {
                 return make_view_closure(bind_back(join_base_fn{}, static_cast<T &&>(t)));
             }
             template(typename T)(
-                /// \pre
                 requires (!joinable_range<T &>) AND range<T &>)
             constexpr auto operator()(T & t) const
             {
@@ -620,13 +616,11 @@ namespace ranges
 
 #if RANGES_CXX_DEDUCTION_GUIDES >= RANGES_CXX_DEDUCTION_GUIDES_17
     template(typename Rng)(
-        /// \pre
         requires views::joinable_range<Rng>)
         explicit join_view(Rng &&)
             ->join_view<views::all_t<Rng>>;
 
     template(typename Rng, typename ValRng)(
-        /// \pre
         requires views::joinable_with_range<Rng, ValRng>)
         explicit join_with_view(Rng &&, ValRng &&)
             ->join_with_view<views::all_t<Rng>, views::all_t<ValRng>>;
@@ -640,11 +634,8 @@ namespace ranges
                 ranges::views::view_closure<ranges::views::cpp20_join_fn>, join)
         }
         template(typename Rng)(
-            /// \pre
             requires input_range<Rng> AND view_<Rng> AND
-                input_range<iter_reference_t<iterator_t<Rng>>> AND
-            (std::is_reference<iter_reference_t<iterator_t<Rng>>>::value ||
-             view_<iter_value_t<iterator_t<Rng>>>)) //
+                input_range<iter_reference_t<iterator_t<Rng>>>) //
             using join_view = ranges::join_view<Rng>;
     } // namespace cpp20
 } // namespace ranges
